/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.rechargerecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.rechargerecord.entity.BizRechargeRecord;
import vip.xiaonuo.biz.modular.rechargerecord.mapper.BizRechargeRecordMapper;
import vip.xiaonuo.biz.modular.rechargerecord.param.BizRechargeRecordAddParam;
import vip.xiaonuo.biz.modular.rechargerecord.param.BizRechargeRecordEditParam;
import vip.xiaonuo.biz.modular.rechargerecord.param.BizRechargeRecordIdParam;
import vip.xiaonuo.biz.modular.rechargerecord.param.BizRechargeRecordPageParam;
import vip.xiaonuo.biz.modular.rechargerecord.service.BizRechargeRecordService;
import vip.xiaonuo.common.util.CommonWxUtil;
import vip.xiaonuo.common.wx.WxPayConfig;

import java.util.List;

/**
 * 充值记录表Service接口实现类
 *
 * @author wulei
 * @date  2025/02/06 17:41
 **/
@Service
public class BizRechargeRecordServiceImpl extends ServiceImpl<BizRechargeRecordMapper, BizRechargeRecord> implements BizRechargeRecordService {

    @Resource
    private CommonWxUtil commonWxUtil;
    @Resource
    private WxPayConfig wxPayConfig;


    @Override
    public Page<BizRechargeRecord> page(BizRechargeRecordPageParam bizRechargeRecordPageParam) {
        QueryWrapper<BizRechargeRecord> queryWrapper = new QueryWrapper<BizRechargeRecord>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizRechargeRecordPageParam.getUserId())) {
            queryWrapper.lambda().like(BizRechargeRecord::getUserId, bizRechargeRecordPageParam.getUserId());
        }
        if(ObjectUtil.isNotEmpty(bizRechargeRecordPageParam.getStartRechargeTime()) && ObjectUtil.isNotEmpty(bizRechargeRecordPageParam.getEndRechargeTime())) {
            queryWrapper.lambda().between(BizRechargeRecord::getRechargeTime, bizRechargeRecordPageParam.getStartRechargeTime(), bizRechargeRecordPageParam.getEndRechargeTime());
        }
        if(ObjectUtil.isAllNotEmpty(bizRechargeRecordPageParam.getSortField(), bizRechargeRecordPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizRechargeRecordPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizRechargeRecordPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizRechargeRecordPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizRechargeRecord::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizRechargeRecordAddParam bizRechargeRecordAddParam) {
        BizRechargeRecord bizRechargeRecord = BeanUtil.toBean(bizRechargeRecordAddParam, BizRechargeRecord.class);
        this.save(bizRechargeRecord);
    }

//    @Transactional(rollbackFor = Exception.class)
//    @Override
//    public void edit(BizRechargeRecordEditParam bizRechargeRecordEditParam) {
//        BizRechargeRecord bizRechargeRecord = this.queryEntity(bizRechargeRecordEditParam.getId());
//        BeanUtil.copyProperties(bizRechargeRecordEditParam, bizRechargeRecord);
//        this.updateById(bizRechargeRecord);
//    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizRechargeRecordIdParam> bizRechargeRecordIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizRechargeRecordIdParamList, BizRechargeRecordIdParam::getId));
    }

    @Override
    public BizRechargeRecord detail(BizRechargeRecordIdParam bizRechargeRecordIdParam) {
        return this.queryEntity(bizRechargeRecordIdParam.getId());
    }

    @Override
    public BizRechargeRecord queryEntity(String id) {
        BizRechargeRecord bizRechargeRecord = this.getById(id);
        if(ObjectUtil.isEmpty(bizRechargeRecord)) {
            throw new CommonException("充值记录表不存在，id值为：{}", id);
        }
        return bizRechargeRecord;
    }
}
